## Pretrained Models 預訓練模型





### Image Classification 圖像識別

|          |   PyTorch    |   PyTorch    |  Tensorflow  | Tensorflow |
| :------: | :----------: | :----------: | :----------: | :--------: |
|          | google drive |   onedrive   | google drive |  onedrive  |
| ResNet18 | [resnet18.pth](https://drive.google.com/open?id=156C4a0_nts8QbjCE8YWbA-QbvCnTrfb5) | resnet18.pth |      -       |     -      |
|ResNet50|[resnet50.pth](https://drive.google.com/open?id=1dYlgpFtqi87KDG54_db4ALWKLARxCWMS)|resnet50.pth|[resnet50_tf.pth](https://drive.google.com/open?id=1vReSW_l8fldyYQ6ay5HCYFGoMaGbdW2T)|resnet50_tf.pth|
|ResNet101|[resnet101.pth](https://drive.google.com/open?id=17moUOsGynsWALLHyv3yprHWbbDMrdiOP)|resnet101.pth|[resnet101_tf.pth](https://drive.google.com/open?id=13QYdFX3CvsNiegi-iUX1PUC0KKKgPNwr)|resnet101_tf.pth|
|ResNet152|[resnet152.pth](https://drive.google.com/open?id=1BIaHb7_qunUVvt4TDAwonSKI2jYg4Ybj)|resnet152.pth|[resnet152_tf.pth](https://drive.google.com/open?id=1TeVBB5ynW9E4_EgxIdjugLT8oaXnQH_c)|resnet152_tf.pth|
|EfficientNetB0|[efficientnet-b0.pth](https://drive.google.com/open?id=1bxnoDerzoNfiZZLft4ocD3DAgx4v6aTN)|efficientnet-b0.pth|[efficientnet-b0_tf.pth](https://drive.google.com/open?id=1pO4wRWY6N4e7U_7E2H-NhBPEF4MlR4ru)|efficientnet-b0_tf.pth|
|EfficientNetB1|[efficientnet-b1.pth](https://drive.google.com/open?id=1F3BtnAjmDz4G9RS9Q0hqU_K7WWXCni1G)|efficientnet-b1.pth|[efficientnet-b1_tf.pth](https://drive.google.com/open?id=1zCWDn4lwHCn4exAnGfBSPh9YHYTGdIYt)|efficientnet-b1_tf.pth|
|EfficientNetB2|[efficientnet-b2.pth](https://drive.google.com/open?id=1PjqhB7WJasF_hqOwYtSBNSXSGBY-cRLU)|efficientnet-b2.pth|efficientnet-b2_tf.pth|efficientnet-b2_tf.pth|
|EfficientNetB3|[efficientnet-b3.pth](https://drive.google.com/open?id=11tMxdYdFfaEREwnESO4cwjtcoEB42zB_)|efficientnet-b3.pth|efficientnet-b3_tf.pth|efficientnet-b3_tf.pth|
|EfficientNetB4|[efficientnet-b4.pth](https://drive.google.com/open?id=1X4ZOBR_ETRHZJeffJHvCmWTTy9_aW8SP)|efficientnet-b4.pth|efficientnet-b4_tf.pth|efficientnet-b4_tf.pth|
|EfficientNetB5|[efficientnet-b5.pth](https://drive.google.com/open?id=17iTD12G9oW3jYAui84MKtdY4gjd9vpgG)|efficientnet-b5.pth|efficientnet-b5_tf.pth|efficientnet-b5_tf.pth|
|EfficientNetB6|[efficientnet-b6.pth](https://drive.google.com/open?id=1XJrKmcmMObN_nnjP2Z-YH_BQ3img58qF)|efficientnet-b6.pth|efficientnet-b6_tf.pth|efficientnet-b6_tf.pth|
|EfficientNetB7|[efficientnet-b7.pth](https://drive.google.com/open?id=1M2DfvsNPRCWSo_CeXnUCQOR46rvOrhLl)|efficientnet-b7.pth|efficientnet-b7_tf.pth|efficientnet-b7_tf.pth|
|SE_ResNet50|[se_resnet50.pth](https://drive.google.com/open?id=1vq0uueiHXuHSEFhb02GoEuPzLwrDW_Mb)|se_resnet50.pth|se_resnet50_tf.pth|se_resnet50_tf.pth|
|SE_ResNet101|[se_resnet101.pth](https://drive.google.com/open?id=17moUOsGynsWALLHyv3yprHWbbDMrdiOP)|se_resnet101.pth|-|-|
|VGG11|[vgg11.pth](https://drive.google.com/open?id=1PV9-AwgD1v-JxDRzduOjjGduIR7MDhPW)|vgg11.pth|-|-|
|VGG13|[vgg13.pth](https://drive.google.com/open?id=1wx67gmQ8eHWXs2mhJmNl-t-cFNw7dJ7O)|vgg13.pth|-|-|
|VGG16|[vgg16.pth](https://drive.google.com/open?id=1uXiH5MSy1rvxrHjW4uB9E2BHMM8b0Fwr)|vgg16.pth|vgg16_tf.pth|vgg16_tf.pth|
|VGG19|[vgg19.pth](https://drive.google.com/open?id=1nqQJLYMzeiUX9hji39-rrBUG42YyjhYg)|vgg19.pth|vgg19_tf.pth|vgg19_tf.pth|
|DenseNet121|[densenet121.pth](https://drive.google.com/open?id=16N2BECErDMRTV5JqESEBWyylXbQmKAIk)|densenet121.pth|densenet121_tf.pth|densenet121_tf.pth|
|DenseNet161|[densenet161.pth](https://drive.google.com/open?id=1n3HRkdPbxKrLVua9gOCY6iJnzM8JnBau)|densenet161.pth|densenet161_tf.pth|densenet161_tf.pth|
|DenseNet169|[densenet169.pth](https://drive.google.com/open?id=1QV73Th0Wo4SCq9AFPVEKqnzs7BUvIG5B)|densenet169.pth|densenet169_tf.pth|densenet169_tf.pth|
|DenseNet201|[densenet201.pth](https://drive.google.com/open?id=1V2JazzdnrU64lDfE-O4bVIgFNQJ38q3J)|densenet201.pth|densenet201_tf.pth|densenet201_tf.pth|
|MobileNetV2|[mobilenet_v2.pth](https://drive.google.com/open?id=1ULenXTjOO5PdT3fHv6N8bPXEfoJAn5yL)|mobilenet_v2.pth|mobilenet_v2_tf.pth|mobilenet_v2_tf.pth|



### Object Detection 目標檢測

|            |   PyTorch    | PyTorch  |  Tensorflow  | Tensorflow |
| :--------: | :----------: | :------: | :----------: | :--------: |
|            | google drive | onedrive | google drive |  onedrive  |
| MTCNN-PNet |   pnet.pth   | pnet.pth |      -       |     -      |
| MTCNN-RNet |   rnet.pth   | rnet.pth |              |            |
| MTCNN-ONet |   onet.pth   | onet.pth |              |            |
|            |              |          |              |            |

